import Vue from 'vue'
import Vuex from 'vuex'

import { getUser, logout } from '@/api/base'
import { getShopList } from '@/api/shop'
import { getGroupList, getFeeTypes } from '@/api/goods'
Vue.use(Vuex)

const store = new Vuex.Store({
  state: {
    user: {},
    shopId: window.localStorage.getItem('shopId') || '', // 店铺ID
    shop: {}, // 店铺信息
    groups: [], // 商品分组
    // 项目列表
    projectList: [
      { label: '玛丽伍德综合管理方向工商管理硕士', value: '1012' },
      { label: '索菲亚大学金融方向工商管理硕士', value: '1000' },
      { label: '瑞士酒店大学酒店及旅游业工商管理硕士', value: '1008' },
      { label: '美国印第安纳大学Kelley商学院金融学硕士', value: '1001' },
      { label: '加州整合大学应用心理学硕士', value: '1006' },
      { label: '美国康博斯威尔大学教育学硕士', value: '1005' },
      { label: '中国未来金融领袖计划', value: '1007' },
      { label: '道路运输企业', value: '5001' }
    ],
    // 费用类型
    feeTypes: []
  },
  mutations: {
    setUser(state, user) {
      state.user = user
    },
    setShopId(state, shopId) {
      state.shopId = shopId
      window.localStorage.setItem('shopId', shopId)
    },
    setShop(state, data) {
      state.shop = data
    },
    setGroups(state, list) {
      state.groups = list
    },
    setFeeTypes(state, list) {
      state.feeTypes = list
    }
  },
  actions: {
    // 获取用户信息
    getUser({ commit }) {
      getUser().then(response => {
        commit('setUser', response)
      })
    },
    // 获取店铺信息
    getShop({ commit, state }) {
      getShopList({ shop_id: state.shopId })
        .then(response => {
          const [first = {}] = response.data || []
          commit('setShop', first)
        })
        .catch(() => {
          commit('setShop', {})
          commit('setShopId', '')
          window.localStorage.removeItem('shopId')
        })
    },
    // 获取商品分组列表
    getGroups({ commit, state }) {
      getGroupList({ shop_id: state.shopId })
        .then(response => {
          const { data = [] } = response
          commit('setGroups', data)
        })
        .catch(() => {
          commit('setGroups', [])
        })
    },
    // 获取费用类型列表
    getFeeTypes({ commit, state }) {
      getFeeTypes()
        .then(response => {
          const { data = [] } = response
          const list = data.map(item => {
            item.type = item.type.toString()
            return item
          })
          commit('setFeeTypes', list)
        })
        .catch(() => {
          commit('setFeeTypes', [])
        })
    },
    // 设置店铺id
    setShopId({ commit }, shopId) {
      commit('setShopId', shopId)
    },
    // 退出登录
    logout({ commit }) {
      return logout().then(response => {
        commit('setUser', {})
        return response
      })
    },
    // 检测登录状态
    async checkLogin({ commit }) {
      const isLogin = await getUser()
        .then(response => {
          commit('setUser', response.data)
          return true
        })
        .catch(() => {
          commit('setUser', {})
          return false
        })
      return isLogin
    }
  }
})

export default store
